===============================
Amadeus Python Library
===============================

.. image:: https://img.shields.io/travis/ardydedase/amadeus-python.svg
        :target: https://travis-ci.org/ardydedase/amadeus-python

.. image:: https://img.shields.io/pypi/v/amadeus.svg
        :target: https://pypi.python.org/pypi/amadeus

.. image:: https://readthedocs.org/projects/amadeus/badge/?version=latest
:target: https://readthedocs.org/projects/amadeus/?badge=latest
:alt: Documentation Status

Python Package for Amadeus Travel Innovation Sandbox

* Free software: BSD license
* Sandbox API Documentation: https://sandbox.amadeus.com/apis
* Python Package Documentation: https://amadeus.readthedocs.org.

Features
--------

* Supports Flights, Hotels and Cars.
* Tested on Python 2.7 for this release.

Installation
------------

At the command line::

    $ pip install amadeus

Or::

    $ easy_install amadeus

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv amadeus
    $ pip install amadeus

Usage
-----
http://amadeus.readthedocs.org/en/latest/usage.html    